@@ -16,12 +16,18 @@
 
 ### Quantities related to the empirical copula #################################
 
+## DEPRECATED
+Cn <- function(x,w) {
+    .Deprecated("C.n")
+    C.n(w, x)
+}
+
 ##' Empirical copula of X at x
 ##'
 ##' @title Empirical CDF and hence copula of X at x
 ##' @param x (m, d) matrix of evaluation points
 ##' @param X (n, d) matrix of pseudo-data based on which the empirical copula
-##'        is computed (if not pseudo-data already, use do.pobs=TRUE)
+##'        is computed.
 ##' @param offset scaling factor of result which is  sum(....)/(n+offset)
 ##' @param method method string ("C" for C code; "R" for R code)
 ##' @return empirical CDF / copula of X at x
@@ -66,44 +72,32 @@ F.n <- function(x, X, offset=0, method=c("C", "R"))
     }
 }
 
-C.n <- function(u, U, offset=0, method=c("C", "R")) {
-    if(any(U < 0, 1 < U))
-        stop("'U' must be in [0,1].. possibly use 'U=pobs(x)'...")
+C.n <- function(u, X, offset=0, method = c("C", "R")) {
     if(any(u < 0, 1 < u))
         stop("'u' must be in [0,1].")
-    F.n(u, U, offset=offset, method=method)
+    F.n(u, pobs(X), offset=offset, method=method)
 }
 
-Cn <- function(x,w) {
-    .Deprecated("C.n")
-    C.n(w, pobs(x))
-}
-
-
-##' Estimated partial derivatives of a copula given the empirical copula
-##'
-##' @title Estimated partial derivatives of a copula given the empirical copula
-##' @param u (m, d) matrix of evaluation points
-##' @param U (n, d) matrix of pseudo-data based on which the empirical copula
-##'        is computed.
+##' @title Estimated Partial Derivatives of a Copula Given the Empirical Copula
+##' @param u (m, d)-matrix of evaluation points
+##' @param U (n, d)-matrix of pseudo-observations
 ##' @param j.ind dimensions for which the partial derivatives should be estimated
 ##' @param b bandwidth in (0, 1/2) for the approximation
 ##' @param ... additional arguments passed to F.n()
 ##' @return (m, length(j.ind))-matrix containing the estimated partial
 ##'         derivatives with index j.ind of the empirical copula of U at u
 ##' @author Marius Hofert
-##' Note: maybe provide a C version (as for F.n) with .Call
 dCn <- function(u, U, j.ind=1:d, b=1/sqrt(nrow(U)), ...)
 {
-    ## check
+    ## Check
     if(!is.matrix(u)) u <- rbind(u, deparse.level=0L)
     if(!is.matrix(U)) U <- rbind(U, deparse.level=0L)
     stopifnot((d <- ncol(U)) == ncol(u),
               0 <= u, u <= 1, 0 <= U, U <= 1,
               1 <= j.ind, j.ind <= d, 0 < b, b < 0.5)
 
-    ## functions to change the entry in the jth column of u
-    ## see Remillard, Scaillet (2009) "Testing for equality between two copulas"
+    ## Functions to change the entry in the jth column of u
+    ## See Remillard, Scaillet (2009) "Testing for equality between two copulas"
     adj.u.up <- function(x){
         x. <- x + b
         x.[x > 1-b] <- 1
@@ -136,29 +130,3 @@ dCn <- function(u, U, j.ind=1:d, b=1/sqrt(nrow(U)), ...)
     if(length(j.ind)==1) as.vector(res) else res
 }
 
-##' Given an (n, d) matrix U and an (m, d) matrix u, compute the (d, n, m) array
-##' of logicals whether U[i,j] <= u[k,j].
-##'
-##' @title Compute an (d, n, m) array of logicals for two matrices with equal
-##'        column number
-##' @param u (m, d) matrix
-##' @param U (n, d) matrix
-##' @return (d, n, m) array of logicals, where [j,i,k] indicates whether
-##'         U[i,j] <= u[k,j]
-##' @author Marius Hofert
-##' Note: - apply() would give an (n*d, m) matrix
-##'       - meant to be called only once, with pseudo-observations U and
-##'         evaluation points u
-##'       - required for efficient multiplier bootstrap,
-##'         where we don't just compare U with u multiple times
-##'       - well, actually, we only need this twice (and have to call C.n with
-##'         adjusted arguments u d times anyways...)
-##' ### MM: not exported, nor documented, nor used *ANYWHERE* in copula pkg
-pobsInd <- function(u, U)
-{
-    stopifnot(length(du <- dim(u)) == 2,
-	      length(dU <- dim(U)) == 2, dU[2] == du[2])
-    tU <- t(U) ## MM: even faster with tu <- t(u);  U <= tu[,k] .. needs more work
-    vapply(seq_len(du[1]), function(k) tU <= u[k,],
-	   array(logical(0), dU[2:1]))
-}
